@@ -28,12 +28,13 @@ use std::str::FromStr;
 use thiserror::Error;
 use tiny_keccak::{Hasher, Keccak};
 
+use std::fmt;
 use std::io;
 
 use crate::blockchain::{Asset, Fee, FeeStrategy, Network, Timelock};
 use crate::consensus::{self, serialize, serialize_hex, CanonicalBytes, Decodable, Encodable};
 #[cfg(feature = "serde")]
-use crate::hash::HashString;
+use crate::hash::{HashString, OfferString};
 use crate::role::{SwapRole, TradeRole};
 use crate::swap::Swap;
 
@@ -165,6 +166,21 @@ impl<Ctx: Swap> std::hash::Hash for Offer<Ctx> {
     }
 }
 
+impl<Ctx: Swap> fmt::Display for Offer<Ctx> {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        writeln!(f, "Network: {}", self.network)?;
+        writeln!(f, "Blockchain: {}", self.arbitrating_blockchain)?;
+        writeln!(f, "- amount: {}", self.arbitrating_amount)?;
+        writeln!(f, "Blockchain: {}", self.accordant_blockchain)?;
+        writeln!(f, "- amount: {}", self.accordant_amount)?;
+        writeln!(f, "Timelocks")?;
+        writeln!(f, "- cancel: {}", self.cancel_timelock)?;
+        writeln!(f, "- punish: {}", self.punish_timelock)?;
+        writeln!(f, "Fee strategy: {}", self.fee_strategy)?;
+        writeln!(f, "Maker swap role: {}", self.maker_role)
+    }
+}
+
 impl<Ctx: Swap> Offer<Ctx> {
     /// Transform the offer in a public offer of [`Version`] 1.
     pub fn to_public_v1(
@@ -469,6 +485,21 @@ impl<'de> Deserialize<'de> for PublicOfferId {
     }
 }
 
+impl Encodable for PublicOfferId {
+    fn consensus_encode<W: io::Write>(&self, s: &mut W) -> Result<usize, io::Error> {
+        self.0.consensus_encode(s)
+    }
+}
+
+impl Decodable for PublicOfferId {
+    fn consensus_decode<D: io::Read>(d: &mut D) -> Result<Self, consensus::Error> {
+        let bytes: [u8; 32] = Decodable::consensus_decode(d)?;
+        Ok(Self::from_slice(&bytes))
+    }
+}
+
+impl_strict_encoding!(PublicOfferId);
+
 /// A public offer is shared across [`TradeRole::Maker`]'s prefered network to signal is willing of
 /// trading some assets at some conditions. The assets and condition are defined in the [`Offer`],
 /// maker peer connection information are contained in the public offer.
@@ -552,6 +583,37 @@ where
     }
 }
 
+// TODO: implement properly without encoding in base58 first
+#[cfg(feature = "serde")]
+impl<Ctx> Serialize for PublicOffer<Ctx>
+where
+    Ctx: Swap,
+{
+    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
+    where
+        S: Serializer,
+    {
+        serializer.serialize_str(self.to_string().as_ref())
+    }
+}
+
+// TODO: implement properly without decoding from base58
+#[cfg(feature = "serde")]
+impl<'de, Ctx> Deserialize<'de> for PublicOffer<Ctx>
+where
+    Ctx: Swap,
+{
+    fn deserialize<D>(deserializer: D) -> Result<PublicOffer<Ctx>, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        Ok(
+            PublicOffer::from_str(&deserializer.deserialize_string(OfferString)?)
+                .map_err(de::Error::custom)?,
+        )
+    }
+}
+
 impl<Ctx> Encodable for PublicOffer<Ctx>
 where
     Ctx: Swap,
@@ -662,9 +724,39 @@ mod tests {
         }
     }
 
+    #[test]
+    fn display_offer() {
+        assert_eq!(&format!("{}", *OFFER), "Network: Testnet\nBlockchain: Bitcoin<SegwitV0>\n- amount: 0.00001350 BTC\nBlockchain: Monero\n- amount: 0.000000010000 XMR\nTimelocks\n- cancel: 4 blocks\n- punish: 6 blocks\nFee strategy: Fixed: 1 satoshi/vByte\nMaker swap role: Bob\n");
+    }
+
     #[test]
     fn display_public_offer() {
         let pub_offer = OFFER.clone().to_public_v1(*NODE_ID, *PEER_ADDRESS);
         assert_eq!(&format!("{}", pub_offer), S);
     }
+
+    #[test]
+    #[cfg(feature = "serde")]
+    fn serialize_public_offer_in_yaml() {
+        let public_offer =
+            PublicOffer::<BtcXmr>::from_str("Offer:Cke4ftrP5A71W723UjzEWsNR4gmBqNCsR11111uMFubBevJ2E5fp6ZR11111TBALTh113GTvtvqfD1111114A4TTfifktDH7QZD71vpdfo6EVo2ds7KviHz7vYbLZDkgsMNb11111111111111111111111111111111111111111AfZ113XRBum3er3R")
+            .expect("Valid public offer");
+        let s = serde_yaml::to_string(&public_offer).expect("Encode public offer in yaml");
+        assert_eq!(
+            "---\n\"Offer:Cke4ftrP5A71W723UjzEWsNR4gmBqNCsR11111uMFubBevJ2E5fp6ZR11111TBALTh113GTvtvqfD1111114A4TTfifktDH7QZD71vpdfo6EVo2ds7KviHz7vYbLZDkgsMNb11111111111111111111111111111111111111111AfZ113XRBum3er3R\"\n",
+            s
+        );
+    }
+
+    #[test]
+    #[cfg(feature = "serde")]
+    fn deserialize_public_offer_from_yaml() {
+        let s = "---\nOffer:Cke4ftrP5A71W723UjzEWsNR4gmBqNCsR11111uMFubBevJ2E5fp6ZR11111TBALTh113GTvtvqfD1111114A4TTfifktDH7QZD71vpdfo6EVo2ds7KviHz7vYbLZDkgsMNb11111111111111111111111111111111111111111AfZ113XRBum3er3R\n";
+        let public_offer = serde_yaml::from_str(&s).expect("Decode public offer from yaml");
+        assert_eq!(
+            PublicOffer::<BtcXmr>::from_str("Offer:Cke4ftrP5A71W723UjzEWsNR4gmBqNCsR11111uMFubBevJ2E5fp6ZR11111TBALTh113GTvtvqfD1111114A4TTfifktDH7QZD71vpdfo6EVo2ds7KviHz7vYbLZDkgsMNb11111111111111111111111111111111111111111AfZ113XRBum3er3R")
+                .expect("Valid public offer"),
+            public_offer
+        );
+    }
 }
